@@ -16,16 +16,11 @@ and python3 in order to be able to run with any python interpreter
 support python2 syntax).
 
 pyqode is made up of the following top level packages/modules:
+
     - frontend: any class/function used to implement the client
                 side GUI application
     - backend: any class/function used to implement the server side application
-    - helpers: various helpers not directly related to CodeEdit (such as
-               a recent files manager)
-    - actions.py: global default values for editor actions
-    - settings.py: global default values for editor settings. This module
-      is usually used by both the backend and the frontend.
-    - style.py: global default values for editor style settings.
 
 """
 
-__version__ = '2.0.0-alpha1'
+__version__ = '2.1.0-dev'
