@@ -8,9 +8,8 @@ Installation:
 run designer.pyw (Qt Designer must be installed on your system and must be
 in your path on Windows)
 """
-# pylint: skip-file
 # This only works with PyQt, PySide does not support the QtDesigner module
-from pyqode.python.code_edit import PyCodeEdit
+from pyqode.python.widgets.code_edit import PyCodeEdit
 from pyqode.core.designer_plugins import WidgetPlugin
 
 
