@@ -1,6 +1,6 @@
 from pyqode.core.api import TextHelper
-from pyqode.core.qt import QtCore
-from pyqode.core.qt.QtTest import QTest
+from pyqode.qt import QtCore
+from pyqode.qt.QtTest import QTest
 from pyqode.python import panels
 
 
@@ -21,12 +21,12 @@ def test_get_doc(editor):
     assert not panel.isVisible()
     editor.setPlainText('open')
     TextHelper(editor).goto_line(1, 1)
-    QTest.keyPress(panel, QtCore.Qt.Key_Q, QtCore.Qt.AltModifier)
-    QTest.qWait(1000)
+    panel._on_action_quick_doc_triggered()
+    QTest.qWait(2000)
     assert panel.isVisible()
     assert 'open' in panel.text_edit.toPlainText()
     editor.clear()
-    QTest.keyPress(panel, QtCore.Qt.Key_Q, QtCore.Qt.AltModifier)
+    panel._on_action_quick_doc_triggered()
     QTest.qWait(1000)
     assert panel.isVisible()
     assert panel.text_edit.toPlainText() == 'Documentation not found'
